@@ -102,22 +102,22 @@ class LogHandle(object):
                     self.__write_to_log(*args)
 
     def gui_console(self, title=None, destroy=False, turn_off=False, gui_obj=None):
-        self.__write_pipe.send({'command': 'gui_console','title': title, 'destroy': destroy, 'turn_off': turn_off,
-                                'gui_obj': gui_obj})
+        if gui_obj and hasattr(gui_obj, "print_gui") and hasattr(gui_obj, "log_setup"):
+            self.__gui_console = gui_obj
+            self.__gui_console.log_setup(log_class=self)
+        else:
+            self.__write_pipe.send({'command': 'gui_console','title': title, 'destroy': destroy, 'turn_off': turn_off})
 
     def write_to_log(self, message, action='info', print_only=False):
         self.__write_pipe.send({'command': 'write_to_log', 'message': message, 'action': action,
                                 'print_only': print_only})
 
-    def __gui_console_set(self, title=None, destroy=False, turn_off=False, gui_obj=None, *args, **kwargs):
+    def __gui_console_set(self, title=None, destroy=False, turn_off=False, *args, **kwargs):
         if self.__gui_console and destroy:
             self.__gui_console.destroy()
             self.__gui_console = None
         elif self.__gui_console and turn_off:
             self.__gui_console = None
-        elif gui_obj and hasattr(gui_obj, "print_gui") and hasattr(gui_obj, "log_setup"):
-            self.__gui_console = gui_obj
-            self.__gui_console.log_setup(log_class=self)
         else:
             self.__gui_console = GUIConsole(parent=self, title=title)
 
